OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "¡No se puede escribir en el directorio \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Esto puede solucionarse fácilmente dándole al servidor permisos de escritura del directorio de configuración",
    "See %s" : "Mirar %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Esto puede solucionarse fácilmente %sotorgándole permisos de escritura al directorio de configuración%s.",
    "Sample configuration detected" : "Ejemplo de configuración detectado",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Se ha detectado que el ejemplo de configuración ha sido copiado. Esto puede arruinar su instalación y es un caso para el que no se brinda soporte. Lea la documentación antes de hacer cambios en config.php",
    "PHP %s or higher is required." : "Se requiere PHP %s o superior.",
    "PHP with a version lower than %s is required." : "PHP con una versión inferior que %s la requerida.",
    "Following databases are supported: %s" : "Las siguientes bases de datos están soportadas: %s",
    "The command line tool %s could not be found" : "No se encontró la herramienta %s de línea de comandos",
    "The library %s is not available." : "La biblioteca %s no está disponible",
    "Library %s with a version higher than %s is required - available version %s." : "Biblioteca %s con una versión superior que %s la requerida - versión disponible %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Biblioteca %s con una versión inferior que %s la requerida - versión disponible %s.",
    "Following platforms are supported: %s" : "Las siguientes plataformas están soportadas: %s",
    "ownCloud %s or higher is required." : "Se requiere ownCloud %s o superior.",
    "ownCloud %s or lower is required." : "Se requiere ownCloud %s o una versión inferior.",
    "Help" : "Ayuda",
    "Personal" : "Personal",
    "Users" : "Usuarios",
    "Admin" : "Administración",
    "Recommended" : "Recomendado",
    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "La App \"%s\" no puede ser instalada porque no es compatible con esta versión de ownCloud.",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "La app \"%s\" no puede instalarse porque las siguientes dependencias no están cumplimentadas: %s",
    "No app name specified" : "No se ha especificado nombre de la aplicación",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Invalid image" : "Imagen inválida",
    "today" : "hoy",
    "yesterday" : "ayer",
    "_%n day ago_::_%n days ago_" : ["Hace %n día","hace %n días"],
    "last month" : "mes pasado",
    "_%n month ago_::_%n months ago_" : ["Hace %n mes","Hace %n meses"],
    "last year" : "año pasado",
    "_%n year ago_::_%n years ago_" : ["Hace %n año","hace %n años"],
    "_%n hour ago_::_%n hours ago_" : ["Hace %n hora","Hace %n horas"],
    "_%n minute ago_::_%n minutes ago_" : ["Hace %n minuto","Hace %n minutos"],
    "seconds ago" : "hace segundos",
    "web services under your control" : "Servicios web bajo su control",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Módulo con id: %s no existe. Por favor habilítelo en los ajustes de sus aplicaciones o contáctese con su administrador.",
    "Empty filename is not allowed" : "No se puede dejar el nombre en blanco.",
    "Dot files are not allowed" : "Los archivos Dot no están permitidos",
    "4-byte characters are not supported in file names" : " No están permitidos caractéres de 4-bytes",
    "File name is a reserved word" : "El nombre de archivo es una palabra reservada",
    "File name contains at least one invalid character" : "El nombre del archivo contiene al menos un carácter inválido",
    "File name is too long" : "El nombre del archivo es demasiado largo",
    "File is currently busy, please try again later" : "Archivo se encuentra actualmente ocupado, por favor inténtelo de nuevo más tarde",
    "Can't read file" : "No se puede leer archivo",
    "App directory already exists" : "El directorio de la aplicación ya existe",
    "Can't create app folder. Please fix permissions. %s" : "No se puede crear la carpeta de la aplicación. Corrija los permisos. %s",
    "Archive does not contain a directory named %s" : "El archivo no contiene un directorio llamado %s",
    "No source specified when installing app" : "No se ha especificado origen cuando se ha instalado la aplicación",
    "No href specified when installing app from http" : "No href especificado cuando se ha instalado la aplicación",
    "No path specified when installing app from local file" : "Ninguna ruta especificada al instalar la aplicación desde el fichero local",
    "Archives of type %s are not supported" : "Los ficheros de tipo %s no son soportados",
    "Failed to open archive when installing app" : "Falló la apertura ded fichero mientras se instalaba la aplicación",
    "App does not provide an info.xml file" : "La aplicación no suministra un fichero info.xml",
    "Signature could not get checked. Please contact the app developer and check your admin screen." : "La firma no pudo ser evaluada. Por favor, contacte con el desarrollador de la aplicación y compruebe su pantalla de administración.",
    "App can't be installed because of not allowed code in the App" : "La aplicación no puede ser instalada por tener código no autorizado en la aplicación",
    "App can't be installed because it is not compatible with this version of ownCloud" : "La aplicación no se puede instalar porque no es compatible con esta versión de ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "La aplicación no se puede instalar porque contiene la etiqueta\n<shipped>\ntrue\n</shipped>\nque no está permitida para aplicaciones no distribuidas",
    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "La App no se puede instalar debido a que la versión de info.xml no es la misma que la versión reportada por la App Store.",
    "Application is not enabled" : "La aplicación no está habilitada",
    "Authentication error" : "Error de autenticación",
    "Token expired. Please reload page." : "Token expirado. Por favor, recarge la página.",
    "Unknown user" : "Usuario desconocido",
    "%s enter the database username." : "%s ingresar el usuario de la base de datos.",
    "%s enter the database name." : "%s ingresar el nombre de la base de datos",
    "%s you may not use dots in the database name" : "%s puede utilizar puntos en el nombre de la base de datos",
    "Oracle connection could not be established" : "No se pudo establecer la conexión a Oracle",
    "Oracle username and/or password not valid" : "Usuario y/o contraseña de Oracle no válidos",
    "DB Error: \"%s\"" : "Error BD: \"%s\"",
    "Offending command was: \"%s\"" : "Comando infractor: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Tiene que ingresar una cuenta existente o la del administrador.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Comando infractor: \"%s\", nombre: %s, contraseña: %s",
    "PostgreSQL username and/or password not valid" : "Usuario y/o contraseña de PostgreSQL no válidos",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X no está soportado y %s no funcionará bien en esta plataforma. ¡Úsela bajo su propio riesgo! ",
    "For the best results, please consider using a GNU/Linux server instead." : "Para resultados óptimos, considere utilizar un servidor GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Parece que esta instancia %s está funcionando en un entorno PHP de 32-bits y el open_basedir se ha configurado en php.ini. Esto acarreará problemas con arhivos de tamaño superior a 4GB y resulta totalmente desaconsejado.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, quite el ajuste de open_basedir —dentro de su php.ini— o pásese a PHP de 64 bits.",
    "Set an admin username." : "Configurar un nombre de usuario del administrador",
    "Set an admin password." : "Configurar la contraseña del administrador.",
    "Can't create or write into the data directory %s" : "No es posible crear o escribir en el directorio de datos %s",
    "Invalid Federated Cloud ID" : "ID Nube federada inválida",
    "%s shared »%s« with you" : "%s ha compartido »%s« contigo",
    "%s via %s" : "%s vía %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "No se pudo compartir %s porque el repositorio no permite recursos compartidos del tipo %i",
    "Sharing %s failed, because the file does not exist" : "No se pudo compartir %s porque el archivo no existe",
    "You are not allowed to share %s" : "Usted no está autorizado para compartir %s",
    "Sharing %s failed, because you can not share with yourself" : "Se falló al compartir %s, porque no puedes compartir contigo mismo",
    "Sharing %s failed, because the user %s does not exist" : "Se ha fallado al compartir %s, ya que el usuario %s no existe",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Se ha fallado al compartir %s, ya que el usuario %s no es miembro de ningún grupo del que %s sea miembro",
    "Sharing %s failed, because this item is already shared with %s" : "Se falló al compartir %s, ya que este elemento ya está compartido con %s",
    "Sharing %s failed, because this item is already shared with user %s" : "Compartiendo %s falló, porque este objeto ya se comparte con el usuario %s",
    "Sharing %s failed, because the group %s does not exist" : "Se falló al compartir %s, ya que el grupo %s no existe",
    "Sharing %s failed, because %s is not a member of the group %s" : "Se falló al compartir %s, ya que %s no es miembro del grupo %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Es necesario definir una contraseña para crear un enlace publico. Solo los enlaces protegidos están permitidos",
    "Sharing %s failed, because sharing with links is not allowed" : "Se falló al compartir %s, ya que no está permitida la compartición con enlaces",
    "Not allowed to create a federated share with the same user" : "No se permite crear un recurso compartido federado con el mismo usuario",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Se falló al compartir %s. No se pudo hallar %s, quizás haya un problema de conexión con el servidor.",
    "Share type %s is not valid for %s" : "Compartir tipo %s no es válido para %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "La configuración de permisos para %s ha fallado, ya que los permisos superan los permisos dados a %s",
    "Setting permissions for %s failed, because the item was not found" : "La configuración de permisos para %s ha fallado, ya que no se encontró el elemento ",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "No se puede fijar fecha de caducidad. Los archivos compartidos no pueden caducar más tarde de %s de ser compartidos",
    "Cannot set expiration date. Expiration date is in the past" : "No se puede fijar la fecha de caducidad. La fecha de caducidad está en el pasado.",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "No se puede eliminar la fecha de caducidad. Los archivos compartidos deben tener una fecha de caducidad.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El motor compartido %s debe implementar la interfaz OCP\\Share_Backend",
    "Sharing backend %s not found" : "El motor compartido %s no se ha encontrado",
    "Sharing backend for %s not found" : "Motor compartido para %s no encontrado",
    "Sharing failed, because the user %s is the original sharer" : "Se ha fallado al compartir, ya que el usuario %s es el compartidor original",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Se ha fallado al compartir %s, ya que los permisos superan los permisos otorgados a %s",
    "Sharing %s failed, because resharing is not allowed" : "Se ha fallado al compartir %s, ya que volver a compartir no está permitido",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Se ha fallado al compartir %s porque el motor compartido para %s podría no encontrar su origen",
    "Sharing %s failed, because the file could not be found in the file cache" : "Se ha fallado al compartir %s, ya que el archivo no pudo ser encontrado en el cache de archivo",
    "Cannot increase permissions of %s" : "No se pueden incrementar los permisos de %s",
    "Expiration date is in the past" : "Ha pasado la fecha de caducidad",
    "Cannot set expiration date more than %s days in the future" : "No se puede fijar la fecha de caducidad más de %s días en el futuro.",
    "Could not find category \"%s\"" : "No puede encontrar la categoría \"%s\"",
    "Apps" : "Aplicaciones",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Solo los siguientes caracteres están permitidos en un nombre de usuario: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
    "A valid username must be provided" : "Se debe proporcionar un nombre de usuario válido",
    "Username contains whitespace at the beginning or at the end" : "El nombre de usuario contiene espacios en blanco al principio o al final",
    "A valid password must be provided" : "Se debe proporcionar una contraseña válida",
    "The username is already being used" : "El nombre de usuario ya está en uso",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "No están instalados los drivers de BBDD  (sqlite, mysql, o postgresql)",
    "Microsoft Windows Platform is not supported" : "La plataforma Microsoft Windows no está soportada",
    "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "No está soportado ejecutar el servidor ownCloud en la plataforma Microsoft Windows. Sugerimos que utilice un servidor GNU/Linux en una máquina virtual si no posee opción de migrar de servidor. Encuentre paquetes de GNU/Linux así como implementar máquinas virtuales en <a href=\"%s\">%s</a>. Para migrar instalaciones actuales hacia GNU/Linux puede encontrar algunos consejos y un script de migración en <a href=\"%s\">nuestra documentación</a>.",
    "Cannot write into \"config\" directory" : "No se puede escribir el el directorio de configuración",
    "Cannot write into \"apps\" directory" : "No se puede escribir en el directorio de \"apps\"",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Esto puede solucionarse fácilmente %sdándole permisos de escritura al servidor en el directorio%s de apps o deshabilitando la tienda de apps en el archivo de configuración.",
    "Cannot create \"data\" directory (%s)" : "No puedo crear del directorio \"data\" (%s)",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Esto puede ser solucionado <a href=\"%s\" target=\"_blank\">dando al servidor web permisos de escritura en el directorio raíz</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Los permisos normalmente puede solucionarse %sdándole al servidor permisos de escritura del directorio raíz%s.",
    "Setting locale to %s failed" : "Falló la activación del idioma %s ",
    "Please install one of these locales on your system and restart your webserver." : "Instale uno de estos idiomas en su sistema y reinicie su servidor web.",
    "Please ask your server administrator to install the module." : "Consulte al administrador de su servidor para instalar el módulo.",
    "PHP module %s not installed." : "El módulo PHP %s no está instalado.",
    "PHP setting \"%s\" is not set to \"%s\"." : "La opción PHP \"%s\" no es \"%s\".",
    "Adjusting this setting in php.ini will make ownCloud run again" : "Ajustando esta opción en php.ini permitirá que ownCloud vuelva a funcionar",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload está dispuesta en \"%s\" en lugar del valor esperado \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Para solucionarlo, defina la función <code>mbstring.func_overload</code> a <code>0</code> en su php.ini",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP está aparentemente configurado para eliminar bloques de documentos en línea. Esto hará que varias aplicaciones principales estén inaccesibles.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Probablemente esto venga a causa de la caché o un acelerador, tales como Zend OPcache o eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Los módulos PHP se han instalado, pero aparecen listados como si faltaran",
    "Please ask your server administrator to restart the web server." : "Consulte al administrador de su servidor para reiniciar el servidor web.",
    "PostgreSQL >= 9 required" : "PostgreSQL 9 o superior requerido.",
    "Please upgrade your database version" : "Actualice su versión de base de datos.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor cambie los permisos a 0770 para que el directorio no se pueda mostrar para otros usuarios.",
    "Data directory (%s) is readable by other users" : "El directorio de datos (%s) se puede leer por otros usuarios.",
    "Data directory (%s) must be an absolute path" : "El directorio de datos (%s) debe ser una ruta absoluta",
    "Check the value of \"datadirectory\" in your configuration" : "Compruebe el valor de \"datadirectory\" en su configuración.",
    "Data directory (%s) is invalid" : "El directorio de datos (%s) no es válido",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Verifique que el directorio de datos contiene un archivo \".ocdata\" en su directorio raíz.",
    "Could not obtain lock type %d on \"%s\"." : "No se pudo realizar el bloqueo %d en \"%s\".",
    "Storage unauthorized. %s" : "Almacenamiento no autorizado. %s",
    "Storage incomplete configuration. %s" : "Configuración de almacenamiento incompleta. %s",
    "Storage connection error. %s" : "Error de conexión de almacenamiento. %s",
    "Storage not available" : "Almacenamiento no disponible",
    "Storage connection timeout. %s" : "Tiempo de conexión de almacenamiento agotado. %s"
},
"nplurals=2; plural=(n != 1);");
